@@ -1,4 +1,4 @@
-package URI::Query::FromHash 0.002;
+package URI::Query::FromHash 0.003;
 
 use strict;
 use warnings;
@@ -40,4 +40,10 @@ sub hash2query(+%) {
     $q;
 }
 
+sub unimport {
+    no strict 'refs';
+
+    delete ${ caller . '::' }{hash2query};
+}
+
 1;
